{% extends 'base.html' %}

{% load i18n %}
{% load static %}

{% block extra_js %}
    <script src="{% static 'js/endless/endless-pagination.js' %}"></script>
    <script>$.endlessPaginate({paginateOnScroll: true});</script>
{% endblock %}

{% block content %}

<div class="container">
	<div class="endless_page_template">
		<div class="panel panel-default" >
	        <div class="panel-heading">
	            <div class="panel-title text-center">{% trans "Notifications" %}</div>
	        </div>
	        <div class="panel-body">
	        	{% include "musette/all_notification.html" %}
	        </div>
	    </div>
	</div>
</div>
{% endblock %}