{% load i18n %}
{% load forum_filter %}

<li class="dropdown without-style-list btn btn-sm pull-right" id="notifications_dropdown">
  	<a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-expanded="false">
  		{% if user.id|get_pending_notifications > 0 %}
  		<span id="badge_notifications" class="badge">{{user.id|get_pending_notifications}}</span>
  		{% endif %}
  		<span class="without-text-transform"> {% trans "Notifications" %}</span>
		<span class="caret"></span>
  	</a>
  	<ul class="dropdown-menu dropdown-cart" role="menu">
  		{% for notification in notifications|slice:"5" %}
  			<li class="item-notification">
		        <span class="item">
		            <span class="item-left">
		            	{% if notification.is_view %}
							{{notification|get_item_notification|safe}}
		            	{% else %}
							{{notification|get_item_notification|safe}}
		            	{% endif %}
		            </span>
		        </span>
		    </li>
      {% empty %}
          <center><p class="without-text-transform">{% trans "No notifications" %}</p></center>
  		{% endfor %}
        <li class="divider"></li>
        <li><a class="text-center" href="/forum_all_notification/">
        	<span class="without-text-transform">
        		<span class="glyphicon glyphicon-envelope"></span>
        		{% trans "All" %}
        	</span>
        </a></li>
  	</ul>
</li>
